-----------------------------------------------------
-- Beispielskript zur SNEK 3 im Mrz 2014 in Nrnberg
-- Autor: Bernd Jungbluth
-- Keine Gewhrleistung, keine Haftung
-----------------------------------------------------

USE Demo_InMemory
GO

-- XTP-Tabelle mit Hash-Index als Primrschlssel anlegen
CREATE TABLE dbo.Staaten
(
	StaatenID	integer NOT NULL,
	Land		nvarchar(250) NOT NULL,
	PRIMARY KEY NONCLUSTERED HASH (StaatenID) WITH (BUCKET_COUNT = 100)
)
WITH (MEMORY_OPTIMIZED = ON, DURABILITY = SCHEMA_AND_DATA);


-- XTP-Tabelle mit nonclustered Range Index als Primrschlssel anlegen
CREATE TABLE dbo.Orte
(
	OrteID		integer NOT NULL,
	Ort			nvarchar(250) NOT NULL,
	PRIMARY KEY NONCLUSTERED (OrteID) 
)
WITH (MEMORY_OPTIMIZED = ON, DURABILITY = SCHEMA_AND_DATA);


-- XTP-Tabelle mit benannten Hash-Index als Primrschlssel anlegen
CREATE TABLE dbo.Regionen
(
	RegionenID	integer NOT NULL 
				CONSTRAINT xHI_Regionen_RegionenID 
				PRIMARY KEY NONCLUSTERED HASH WITH (BUCKET_COUNT = 100),
	Region		nvarchar(250) NOT NULL 
)
WITH (MEMORY_OPTIMIZED = ON, DURABILITY = SCHEMA_AND_DATA);


-- XTP-Tabelle mit DURABILITY = SCHEMA_ONLY anlegen
-- Kein Primrschlssel, aber ein Index erforderlich
-- Daten sind nur im Arbeitsspeicher vorhanden!
CREATE TABLE dbo.Eigenschaften
(
	Eigenschaft	nvarchar(50) COLLATE Latin1_General_100_BIN2 NOT NULL,
	Wert		nvarchar(250),
	INDEX xHI_Eigenschaften_Eigenschaft 
		  NONCLUSTERED HASH (Eigenschaft) WITH (BUCKET_COUNT = 100),
)
WITH (MEMORY_OPTIMIZED = ON, DURABILITY = SCHEMA_ONLY);


-- XTP-Tabelle mitHash-Index als Primrschlssel und Hash-Index auf 
-- 2 Spalten und einen nonclustered Index anlegen
-- Bei Spalten mit Zeichenfolgen im Index COLLATION BIN2 erforderlich
CREATE TABLE dbo.Personal
(
	PersonalID		integer NOT NULL
					CONSTRAINT xHI_PK_Personal_PersonalID 
					PRIMARY KEY NONCLUSTERED HASH WITH (BUCKET_COUNT = 100),
	Nachname		nvarchar(250) COLLATE Latin1_General_100_BIN2 NOT NULL,
	Vorname			nvarchar(100) COLLATE Latin1_General_100_BIN2 NOT NULL,
	EingestelltAm	datetime NOT NULL,

	INDEX xHI_Personal_Nachname_Vorname 
		  NONCLUSTERED HASH (Nachname, Vorname) WITH (BUCKET_COUNT = 100),
	INDEX xNI_Personal_EingestelltAm 
		  NONCLUSTERED (EingestelltAm)
)
WITH (MEMORY_OPTIMIZED = ON, DURABILITY = SCHEMA_AND_DATA);


-- Ermitteln vom Speicherort der DLL zur XTP-Tabelle

-- DatenbankID ermitteln 
-- Entspricht dem Unterverzeichnis fr XTP-Objekte der Datenbank
SELECT db_id() As DatenbankID;

-- ObjectID ermitteln
-- Im Dateinamen des XTP-Objekts enthalten
SELECT OBJECT_ID('dbo.Personal') As ObjektID;

-- Name der geladenen XTP-Objekte ermitteln
-- Datenbank-ID und Objekt-ID im Namen enthalten
SELECT	name As Speicherort
FROM	sys.dm_os_loaded_modules 
WHERE	description = 'XTP Native DLL';

		