-----------------------------------------------------
-- Beispielskript zur SNEK 3 im Mrz 2014 in Nrnberg
-- Autor: Bernd Jungbluth
-- Keine Gewhrleistung, keine Haftung
-----------------------------------------------------

USE master;
GO

-- Neue Datenbank fr Beispiele anlegen
CREATE DATABASE Demo_XTP
ON
PRIMARY(NAME = Demo_XTP, FILENAME = 'D:\SNEK\Datenbanken\Demo_XTP.mdf', SIZE = 1024MB), 
FILEGROUP Demo_XTP_Dateien CONTAINS MEMORY_OPTIMIZED_DATA
(NAME = Demo_XTP_Dateien, FILENAME = 'D:\SNEK\Datenbanken\Demo_XTP\Dateien')
LOG ON (NAME = Demo_XTP_log, FILENAME = 'D:\SNEK\Datenbanken\Demo_XTP.ldf', SIZE = 500MB);
GO


USE Demo_XTP;
GO

-- Neue XTP-Tabelle anlegen
CREATE TABLE dbo.Kontakte
(
	KontaktID integer NOT NULL
			 CONSTRAINT xHI_PK_Kontakte_KontaktID 
			 PRIMARY KEY NONCLUSTERED HASH WITH (BUCKET_COUNT = 50000),
	Name	 nvarchar(250), 
	Land	 nvarchar(250) COLLATE Latin1_General_100_BIN2 NOT NULL
	INDEX xHI_Kontakt_Land NONCLUSTERED HASH (Land) WITH (BUCKET_COUNT = 50000)
)
WITH (MEMORY_OPTIMIZED = ON, DURABILITY = SCHEMA_AND_DATA);
GO
-- Im Verzeichnis der FILESTREAM-Dateigruppe sind die Daten- und Deltadateien nun vorhanden.


-- Inhalt der Daten- und Deltadateien anzeigen
SELECT * FROM sys.dm_db_xtp_checkpoint_files 
ORDER BY internal_storage_slot, file_type;


-- XTP-Tabelle mit Daten fllen
DECLARE @Zaehler1 integer = 1,
		@Zaehler2 char(1),
		@Startzeit datetime2 = getdate(),
		@ZeitInMS integer;

BEGIN TRAN
	WHILE @Zaehler1 <= 100000
	BEGIN
		SET @Zaehler2 = LEFT(CAST(@Zaehler1 as nvarchar(7)),1);
		INSERT INTO dbo.Kontakte (KontaktID, Name, Land) 
			 VALUES (@Zaehler1, 'Name' + CAST(@Zaehler1 As nvarchar(7)), 'Land' + @Zaehler2);
		SET @Zaehler1 = @Zaehler1 + 1;
	END;
COMMIT;
-- Daten der XTP-Tabelle anzeigen
SELECT TOP 100 KontaktID, Name, Land FROM dbo.Kontakte;


-- Inhalt der Daten- und Deltadateien anzeigen
SELECT	file_type, file_type_desc, internal_storage_slot, file_size_in_bytes, 
		file_size_used_in_bytes, inserted_row_count, deleted_row_count, is_active
FROM	sys.dm_db_xtp_checkpoint_files 
WHERE	internal_storage_slot Is Not Null
ORDER BY internal_storage_slot, file_type;

-- Prfpunkt auslsen
CHECKPOINT;

-- Inhalt der Daten- und Deltadateien anzeigen
-- Daten der XTP-Tabelle sind nun in den Daten- und Deltadateien gespeichert
SELECT	file_type, file_type_desc, internal_storage_slot, file_size_in_bytes, 
		file_size_used_in_bytes, inserted_row_count, deleted_row_count, is_active
FROM	sys.dm_db_xtp_checkpoint_files 
WHERE	internal_storage_slot Is Not Null
ORDER BY internal_storage_slot, file_type;


-- Daten ndern
UPDATE TOP (5000) dbo.Kontakte SET Land = 'Bayern' WHERE Land = 'Land5';
SELECT TOP 100 KontaktID, Name, Land FROM dbo.Kontakte ORDER BY Land;
CHECKPOINT;
SELECT	file_type, file_type_desc, internal_storage_slot, file_size_in_bytes, 
		file_size_used_in_bytes, inserted_row_count, deleted_row_count, is_active
FROM	sys.dm_db_xtp_checkpoint_files 
WHERE	internal_storage_slot Is Not Null
ORDER BY internal_storage_slot, file_type;


-- Daten lschen
DELETE TOP (100) FROM dbo.Kontakte WHERE Land = 'Land4';
CHECKPOINT;
SELECT	file_type, file_type_desc, internal_storage_slot, file_size_in_bytes, 
		file_size_used_in_bytes, inserted_row_count, deleted_row_count, is_active
FROM	sys.dm_db_xtp_checkpoint_files 
WHERE	internal_storage_slot Is Not Null
ORDER BY internal_storage_slot, file_type;