-----------------------------------------------------
-- Beispielskript zur SNEK 3 im Mrz 2014 in Nrnberg
-- Autor: Bernd Jungbluth
-- Keine Gewhrleistung, keine Haftung
-----------------------------------------------------

USE Demo_XTP;
GO

-- XTP-Tabelle zur Auswertung der Performance anlegen 
CREATE TABLE dbo.Performancevergleich(
	PVID int NOT NULL,
	Methode nvarchar(50) NOT NULL,
	AnzahlDatensaetze int NOT NULL,
	DauerInMs int NOT NULL,
	PRIMARY KEY NONCLUSTERED HASH (PVID) WITH (BUCKET_COUNT = 100))
WITH (MEMORY_OPTIMIZED = ON, DURABILITY = SCHEMA_AND_DATA);
GO


-- Herkmmliche Tabelle fr Performancevergleich anlegen 
CREATE TABLE dbo.Kunden
(
	KundenID integer NOT NULL CONSTRAINT CIX_PK_Kunden_KundenID PRIMARY KEY,
	Firma	 nvarchar(250) NOT NULL,
	Land	 nvarchar(259) NOT NULL	INDEX IX_Kunden_Land 
);
-- Neue Syntax in T-SQL mglich; Inlinedefinition eines Index


-- XTP-Tabelle fr Performancevergleich anlegen
CREATE TABLE dbo.KundenXTP
(
	KundenID integer NOT NULL
			 CONSTRAINT xHI_PK_KundenXTP_KundenID 
			 PRIMARY KEY NONCLUSTERED HASH WITH (BUCKET_COUNT = 50000),
	Firma	 nvarchar(250), 
	Land	 nvarchar(250) COLLATE Latin1_General_100_BIN2 NOT NULL
	INDEX xHI_KundenXTP_Land NONCLUSTERED HASH (Land) WITH (BUCKET_COUNT = 50000)
)
WITH (MEMORY_OPTIMIZED = ON, DURABILITY = SCHEMA_AND_DATA);
GO

-- Informationsmeldungen ausschalten
SET NOCOUNT ON;

-- Herkmmliche Tabelle fllen
DECLARE @Zaehler1 integer = 0,
		@Zaehler2 char(1),
		@Startzeit datetime2 = sysdatetime(),
		@ZeitInMS integer;

BEGIN TRAN
	WHILE @Zaehler1 <= 50000
	BEGIN
		SET @Zaehler2 = LEFT(CAST(@Zaehler1 as nvarchar(7)),1);
		INSERT INTO dbo.Kunden (KundenID, Firma, Land) 
			 VALUES (@Zaehler1, 'Firma' + CAST(@Zaehler1 As nvarchar(7)), 'Land' + @Zaehler2);
		SET @Zaehler1 = @Zaehler1 + 1;
	END;
COMMIT;
SET @ZeitInMS = DATEDIFF(ms, @Startzeit, sysdatetime());
SELECT 'herkmmliche Tabelle: ' + CAST(@ZeitInMS As varchar(10)) + ' ms';
INSERT INTO dbo.Performancevergleich (PVID, Methode, AnzahlDatensaetze, DauerInMs) 
	 VALUES (1, 'INSERT in herkmmliche Tabelle', 50000, @ZeitInMS);

-- XTP-Tabelle fllen
DECLARE @xtpZaehler1 integer = 0,
		@xtpZaehler2 char(1),
		@xtpStartzeit datetime2 = sysdatetime(),
		@xtpZeitInMS integer;;

BEGIN TRAN
	WHILE @xtpZaehler1 <= 50000
	BEGIN
		SET @xtpZaehler2 = LEFT(CAST(@xtpZaehler1 as nvarchar(7)),1);
		INSERT INTO dbo.KundenXTP (KundenID, Firma, Land) 
			 VALUES (@xtpZaehler1, 'Firma' + CAST(@xtpZaehler1 As nvarchar(7)), 'Land' + @xtpZaehler2);
		SET @xtpZaehler1 = @xtpZaehler1 + 1;
	END;
COMMIT;
SET @xtpZeitInMS = DATEDIFF(ms, @xtpStartzeit, sysdatetime());
SELECT 'XTP Tabelle: ' + CAST(@xtpZeitInMS As varchar(10)) + ' ms';
INSERT INTO dbo.Performancevergleich (PVID, Methode, AnzahlDatensaetze, DauerInMs) 
	 VALUES (2, 'INSERT in XTP-Tabelle', 50000, @xtpZeitInMS);
GO

-- Ausgabe der gemessenen Zeiten
SELECT 	PVID, Methode, AnzahlDatensaetze, DauerInMs 
FROM	dbo.Performancevergleich
ORDER BY PVID;