-----------------------------------------------------
-- Beispielskript zur SNEK 3 im Mrz 2014 in Nrnberg
-- Autor: Bernd Jungbluth
-- Keine Gewhrleistung, keine Haftung
-----------------------------------------------------

USE Demo_XTP;
GO

-- Herkmmliche Gespeicherte Prozedur zum Fllen der herkmmlichen Tabelle anlegen
CREATE PROC dbo.pKunden_Insert (@Anfang int, @Ende int)
AS
SET NOCOUNT ON;

DECLARE @Zaehler1 integer = @Anfang,
		@Zaehler2 char(1),
		@Startzeit datetime2 = sysdatetime(),
		@ZeitInMS integer;

BEGIN TRAN
	WHILE @Zaehler1 <= @Ende
	BEGIN
		SET @Zaehler2 = LEFT(CAST(@Zaehler1 as nvarchar(7)),1);
		INSERT INTO dbo.Kunden (KundenID, Firma, Land) 
			 VALUES (@Zaehler1, 'Firma' + CAST(@Zaehler1 As nvarchar(7)), 'Land' + @Zaehler2);
		SET @Zaehler1 = @Zaehler1 + 1;
	END;
COMMIT;
SET @ZeitInMS = DATEDIFF(ms, @Startzeit, sysdatetime());
SELECT 'Herkmmliche Tabelle mit Gespeicherter Prozedur: ' + CAST(@ZeitInMS As varchar(10)) + ' ms';
INSERT INTO dbo.Performancevergleich (PVID, Methode, AnzahlDatensaetze, DauerInMs) 
	 VALUES (3, 'Prozedur an herkmmlicher Tabelle', 50000, @ZeitInMS);
GO

-- Herkmmliche Gespeicherte Prozedur zum Fllen der XTP-Tabelle anlegen
CREATE PROC dbo.pKundenXTP_Insert (@Anfang int, @Ende int)
AS
SET NOCOUNT ON;
DECLARE @xtpZaehler1 integer = @Anfang,
		@xtpZaehler2 char(1),
		@xtpStartzeit datetime2 = sysdatetime(),
		@xtpZeitInMS integer;;

BEGIN TRAN
	WHILE @xtpZaehler1 <= @Ende
	BEGIN
		SET @xtpZaehler2 = LEFT(CAST(@xtpZaehler1 as nvarchar(7)),1);
		INSERT INTO dbo.KundenXTP (KundenID, Firma, Land) 
			 VALUES (@xtpZaehler1, 'Firma' + CAST(@xtpZaehler1 As nvarchar(7)), 'Land' + @xtpZaehler2);
		SET @xtpZaehler1 = @xtpZaehler1 + 1;
	END;
COMMIT;
SET @xtpZeitInMS = DATEDIFF(ms, @xtpStartzeit, sysdatetime());
SELECT 'XTP Tabelle mit Gespeicherter Prozedur: ' + CAST(@xtpZeitInMS As varchar(10)) + ' ms';
INSERT INTO dbo.Performancevergleich (PVID, Methode, AnzahlDatensaetze, DauerInMs) 
	 VALUES (4, 'Prozedur an XTP-Tabelle', 50000, @xtpZeitInMS);
GO

-- Herkmmliche Gespeicherte Prozedur zum Fllen der herkmmlichen Tabelle ausfhren
EXEC dbo.pKunden_Insert 50001, 100000;
-- Herkmmliche Gespeicherte Prozedur zum Fllen der XTP-Tabelle ausfhren
EXEC dbo.pKundenXTP_Insert 50001, 100000;
GO

-- Ausgabe der gemessenen Zeiten
SELECT 	PVID, Methode, AnzahlDatensaetze, DauerInMs 
FROM	dbo.Performancevergleich
ORDER BY PVID;
GO

-- XTP-Gespeicherte Prozedur zum Fllen der XTP-Tabelle anlegen
CREATE PROCEDURE dbo.npKundenXTP_Insert (@Anfang int, @Ende int)
WITH 
	NATIVE_COMPILATION, SCHEMABINDING, EXECUTE AS OWNER
AS 
BEGIN ATOMIC 
	WITH (TRANSACTION ISOLATION LEVEL = SNAPSHOT, LANGUAGE = 'German')

	DECLARE @xtpZaehler1 integer = @Anfang,
			@xtpZaehler2 char(1),
			@xtpStartzeit datetime2 = sysdatetime(),
			@xtpZeitInMS integer;

	WHILE @xtpZaehler1 <= @Ende
	BEGIN
		SET @xtpZaehler2 = SUBSTRING(CAST(@xtpZaehler1 as nvarchar(7)),1,7);
		INSERT INTO dbo.KundenXTP (KundenID, Firma, Land) 
			 VALUES (@xtpZaehler1, 'Firma' + CAST(@xtpZaehler1 As nvarchar(7)), 'Land' + @xtpZaehler2);
		SET @xtpZaehler1 = @xtpZaehler1 + 1;
	END;
	SET @xtpZeitInMS = DATEDIFF(ms, @xtpStartzeit, sysdatetime());
	SELECT 'XTP Tabelle mit Native Compiled Stored Procedure: ' + CAST(@xtpZeitInMS As varchar(10)) + ' ms';
	INSERT INTO dbo.Performancevergleich (PVID, Methode, AnzahlDatensaetze, DauerInMs) 
	 VALUES (5, 'XTP-Prozedur an XTP-Tabelle', 50000, @xtpZeitInMS);
END
GO

-- XTP-Gespeicherte Prozedur zum Fllen der XTP-Tabelle ausfhren
EXEC dbo.npKundenXTP_Insert 100001, 150000;

-- Ausgabe der gemessenen Zeiten
SELECT 	PVID, Methode, AnzahlDatensaetze, DauerInMs 
FROM	dbo.Performancevergleich
ORDER BY PVID;




-- Ermitteln vom Speicherort der DLL zur XTP-Gespeicherten Prozedur

-- DatenbankID ermitteln 
-- Entspricht dem Unterverzeichnis fr XTP-Objekte der Datenbank
SELECT db_id() As DatenbankID;

-- ObjectID ermitteln
-- Im Dateinamen des XTP-Objekts enthalten
SELECT OBJECT_ID('dbo.Personal') As ObjektID;

-- Name der geladenen XTP-Objekte ermitteln
-- Datenbank-ID und Objekt-ID im Namen enthalten
SELECT	name As Speicherort
FROM	sys.dm_os_loaded_modules 
WHERE	description = 'XTP Native DLL';